@@ -25,11 +25,5 @@ pub mod ipc; // Requires interprocess
 #[cfg(not(target_family = "wasm"))]
 pub mod logging; // Requires log4rs
 
-#[cfg(not(target_family = "wasm"))]
-pub use ::{
-    anyhow, async_channel, async_std, clap, humantime, interprocess, isahc, lazy_static, libc,
-    miette, nix, notify_debouncer_full, regex, serde, signal_hook, tempfile, termwiz, url, uuid,
-    vte,
-};
-
+// TODO(hartan): Remove this re-export for the next minor release.
 pub use ::prost;
